=======
Credits
=======

This project was initiated as part of Antoine COLLET's `PhD <https://theses.fr/s263802>`_
between 2020 and 2024. Although the current version of the covmats code was written
in its entirety by Antoine COLLET and his supervisors Irina SIN and Hervé CHAURIS, researchers
at the Ecole des Mines de Paris.

Development Lead
----------------

* Antoine Collet <antoine.collet5@gmail.com>

Contributors
------------

None yet. Why not be the first?
